@@ -1,5 +1,3 @@
-import warnings
-
 from .. import backend, monoid
 from ..binary import land, lor, pair
 from ..dtypes import BOOL
@@ -33,15 +31,7 @@ class Mask:
     def _carg(self):
         return self.parent.gb_obj[0]
 
-    @property
-    def mask(self):
-        warnings.warn(
-            "`mask.mask` is deprecated; please use `mask.parent` instead.",
-            DeprecationWarning,
-        )
-        return self.parent
-
-    def new(self, dtype=None, *, complement=False, mask=None, name=None):
+    def new(self, dtype=None, *, complement=False, mask=None, name=None, **opts):
         """Return a new object with True values determined by the mask(s).
 
         By default, the result is True wherever the mask(s) would have been applied,
@@ -78,9 +68,9 @@ class Mask:
         if mask is None:
             val = type(self.parent)(dtype, *self.parent.shape, name=name)
             if complement:
-                val(~self) << True
+                val(~self, **opts) << True
             else:
-                val(self) << True
+                val(self, **opts) << True
             return val
 
         from .base import _check_mask
@@ -88,9 +78,9 @@ class Mask:
         mask = _check_mask(mask)
         d = _COMPLEMENT_MASKS if complement else _COMBINE_MASKS
         func = d[type(self), type(mask)]
-        return func(self, mask, dtype, name)
+        return func(self, mask, dtype, name, opts)
 
-    def __and__(self, other):
+    def __and__(self, other, **opts):
         """Return the intersection of two masks as a new mask.
 
         `new_mask = mask1 & mask2` is equivalent to the following:
@@ -109,14 +99,14 @@ class Mask:
         complement = self.complement or other.complement
         d = _COMPLEMENT_MASKS if complement else _COMBINE_MASKS
         func = d[type(self), type(other)]
-        val = func(self, other, bool, None)
+        val = func(self, other, bool, None, opts)
         if complement:
             return ComplementedStructuralMask(val)
         return StructuralMask(val)
 
     __rand__ = __and__
 
-    def __or__(self, other):
+    def __or__(self, other, **opts):
         """Return the union of two masks as a new mask.
 
         `new_mask = mask1 | mask2` is equivalent to the following:
@@ -133,7 +123,7 @@ class Mask:
 
         other = _check_mask(other)
         func = _MASK_OR[type(self), type(other)]
-        return func(self, other)
+        return func(self, other, opts)
 
     __ror__ = __or__
 
@@ -217,64 +207,64 @@ class ComplementedValueMask(Mask):
 #    V: value
 #    CS: complemented structural
 #    CV: complemented value
-def _combine_S_S(m1, m2, dtype, name):
+def _combine_S_S(m1, m2, dtype, name, opts):
     """S-S"""
-    return pair(m1.parent & m2.parent).new(dtype, name=name)
+    return pair(m1.parent & m2.parent).new(dtype, name=name, **opts)
 
 
-def _combine_S_A(m1, m2, dtype, name):
+def _combine_S_A(m1, m2, dtype, name, opts):
     """S-S, S-V, S-CS, S-CV"""
-    return one(m1.parent).new(dtype, mask=m2, name=name)
+    return one(m1.parent).new(dtype, mask=m2, name=name, **opts)
 
 
-def _combine_A_S(m1, m2, dtype, name):
+def _combine_A_S(m1, m2, dtype, name, opts):
     """S-S, V-S, CS-S, CV-S"""
-    return one(m2.parent).new(dtype, mask=m1, name=name)
+    return one(m2.parent).new(dtype, mask=m1, name=name, **opts)
 
 
-def _combine_V_A(m1, m2, dtype, name):
+def _combine_V_A(m1, m2, dtype, name, opts):
     """V-S, V-V, V-CS, V-CV"""
     if isinstance(m2, ValueMask) and m1.parent._nvals > m2.parent._nvals:
         m1, m2 = m2, m1
-    val = valuene(m1.parent).new(dtype, mask=m2, name=name)
+    val = valuene(m1.parent).new(dtype, mask=m2, name=name, **opts)
     if dtype != BOOL or backend != "suitesparse" or not val.ss.is_iso:
-        val(val.S) << True
+        val(val.S, **opts) << True
     return val
 
 
-def _combine_A_V(m1, m2, dtype, name):
+def _combine_A_V(m1, m2, dtype, name, opts):
     """S-V, V-V, CS-V, CV-V"""
-    val = valuene(m2.parent).new(dtype, mask=m1, name=name)
+    val = valuene(m2.parent).new(dtype, mask=m1, name=name, **opts)
     if dtype != BOOL or backend != "suitesparse" or not val.ss.is_iso:
-        val(val.S) << True
+        val(val.S, **opts) << True
     return val
 
 
-def _combine_CS_CS(m1, m2, dtype, name):
+def _combine_CS_CS(m1, m2, dtype, name, opts):
     """CS-CS"""
-    val = pair(m1.parent | m2.parent).new(dtype, name=name)
-    val(~val.S, replace=True) << True
+    val = pair(m1.parent | m2.parent).new(dtype, name=name, **opts)
+    val(~val.S, replace=True, **opts) << True
     return val
 
 
-def _combine_CS_CV(m1, m2, dtype, name):
+def _combine_CS_CV(m1, m2, dtype, name, opts):
     """CS-CV"""
-    val = pair(one(m1.parent).new() | m2.parent).new(dtype, name=name)
-    val(~val.V, replace=True) << True
+    val = pair(one(m1.parent).new(**opts) | m2.parent).new(dtype, name=name, **opts)
+    val(~val.V, replace=True, **opts) << True
     return val
 
 
-def _combine_CV_CS(m1, m2, dtype, name):
+def _combine_CV_CS(m1, m2, dtype, name, opts):
     """CV-CS"""
-    val = pair(m1.parent | one(m2.parent).new()).new(dtype, name=name)
-    val(~val.V, replace=True) << True
+    val = pair(m1.parent | one(m2.parent).new(**opts)).new(dtype, name=name, **opts)
+    val(~val.V, replace=True, **opts) << True
     return val
 
 
-def _combine_CV_CV(m1, m2, dtype, name):
+def _combine_CV_CV(m1, m2, dtype, name, opts):
     """CV-CV"""
-    val = lor(m1.parent | m2.parent).new(dtype, name=name)
-    val(~val.V, replace=True) << True
+    val = lor(m1.parent | m2.parent).new(dtype, name=name, **opts)
+    val(~val.V, replace=True, **opts) << True
     return val
 
 
@@ -309,85 +299,87 @@ _COMBINE_MASKS = {
 
 
 # Recipes to return the *complement* of combining two masks
-def _complement_S_S(m1, m2, dtype, name):
+def _complement_S_S(m1, m2, dtype, name, opts):
     """S-S"""
-    val = pair(m1.parent & m2.parent).new(dtype, name=name)
-    val(~val.S, replace=True) << True
+    val = pair(m1.parent & m2.parent).new(dtype, name=name, **opts)
+    val(~val.S, replace=True, **opts) << True
     return val
 
 
-def _complement_S_A(m1, m2, dtype, name):
+def _complement_S_A(m1, m2, dtype, name, opts):
     """S-S, S-V, S-CS, S-CV"""
-    val = one(m1.parent).new(dtype, mask=m2, name=name)
-    val(~val.S, replace=True) << True
+    val = one(m1.parent).new(dtype, mask=m2, name=name, **opts)
+    val(~val.S, replace=True, **opts) << True
     return val
 
 
-def _complement_A_S(m1, m2, dtype, name):
+def _complement_A_S(m1, m2, dtype, name, opts):
     """S-S, V-S, CS-S, CV-S"""
-    val = one(m2.parent).new(dtype, mask=m1, name=name)
-    val(~val.S, replace=True) << True
+    val = one(m2.parent).new(dtype, mask=m1, name=name, **opts)
+    val(~val.S, replace=True, **opts) << True
     return val
 
 
-def _complement_V_V(m1, m2, dtype, name):
+def _complement_V_V(m1, m2, dtype, name, opts):
     """V-V"""
-    val = land(m1.parent & m2.parent).new(dtype, name=name)
-    val(~val.V, replace=True) << True
+    val = land(m1.parent & m2.parent).new(dtype, name=name, **opts)
+    val(~val.V, replace=True, **opts) << True
     return val
 
 
-def _complement_CS_CS(m1, m2, dtype, name):
+def _complement_CS_CS(m1, m2, dtype, name, opts):
     """CS-CS"""
-    return pair(one(m1.parent).new() | one(m2.parent).new()).new(dtype, name=name)
+    return pair(one(m1.parent).new(**opts) | one(m2.parent).new(**opts)).new(
+        dtype, name=name, **opts
+    )
 
 
-def _complement_CS_A(m1, m2, dtype, name):
+def _complement_CS_A(m1, m2, dtype, name, opts):
     """CS-S, CS-V, CS-CS, CS-CV"""
-    val = one(m1.parent).new(dtype, name=name)
-    val(~m2) << True
+    val = one(m1.parent).new(dtype, name=name, **opts)
+    val(~m2, **opts) << True
     return val
 
 
-def _complement_A_CS(m1, m2, dtype, name):
+def _complement_A_CS(m1, m2, dtype, name, opts):
     """S-CS, V-CS, CS-CS, CV-CS"""
-    val = one(m2.parent).new(dtype, name=name)
-    val(~m1) << True
+    val = one(m2.parent).new(dtype, name=name, **opts)
+    val(~m1, **opts) << True
     return val
 
 
-def _complement_CS_CV(m1, m2, dtype, name):
+def _complement_CS_CV(m1, m2, dtype, name, opts):
     """CS-CV"""
-    val = pair(one(m1.parent).new() | m2.parent).new(dtype, name=name)
-    val(val.V, replace=True) << True
+    val = pair(one(m1.parent).new(**opts) | m2.parent).new(dtype, name=name, **opts)
+    val(val.V, replace=True, **opts) << True
     return val
 
 
-def _complement_CV_CS(m1, m2, dtype, name):
+def _complement_CV_CS(m1, m2, dtype, name, opts):
     """CV-CS"""
-    val = pair(m1.parent | one(m2.parent).new()).new(dtype, name=name)
-    val(val.V, replace=True) << True
+    val = pair(m1.parent | one(m2.parent).new(**opts)).new(dtype, name=name, **opts)
+    val(val.V, replace=True, **opts) << True
     return val
 
 
-def _complement_CV_CV(m1, m2, dtype, name):
+def _complement_CV_CV(m1, m2, dtype, name, opts):
     """CV-CV"""
-    val = lor(m1.parent | m2.parent).new(dtype, name=name)
-    val(val.V, replace=True) << True
+    val = lor(m1.parent | m2.parent).new(dtype, name=name, **opts)
+    val(val.V, replace=True, **opts) << True
     return val
 
 
-def _complement_CV_A(m1, m2, dtype, name):
+def _complement_CV_A(m1, m2, dtype, name, opts):
     """CV-S, CV-V, CV-CS, CV-CV"""
-    val = one(m1.parent).new(dtype, mask=~m1, name=name)
-    val(~m2) << True
+    val = one(m1.parent).new(dtype, mask=~m1, name=name, **opts)
+    val(~m2, **opts) << True
     return val
 
 
-def _complement_A_CV(m1, m2, dtype, name):
+def _complement_A_CV(m1, m2, dtype, name, opts):
     """S-CV, V-CV, CS-CV, CV-CV"""
-    val = one(m2.parent).new(dtype, mask=~m2, name=name)
-    val(~m1) << True
+    val = one(m2.parent).new(dtype, mask=~m2, name=name, **opts)
+    val(~m1, **opts) << True
     return val
 
 
@@ -421,63 +413,71 @@ _COMPLEMENT_MASKS = {
 }
 
 
-def _combine_S_S_mask_or(m1, m2):
+def _combine_S_S_mask_or(m1, m2, opts):
     """S-S"""
-    val = monoid.any(one(m1.parent).new(bool) | one(m2.parent).new(bool)).new()
+    val = monoid.any(one(m1.parent).new(bool, **opts) | one(m2.parent).new(bool, **opts)).new(
+        **opts
+    )
     return StructuralMask(val)
 
 
-def _combine_S_SV_mask_or(m1, m2):
+def _combine_S_SV_mask_or(m1, m2, opts):
     """S-V"""
-    val = monoid.any(one(m1.parent).new(bool) | one(m2.parent).new(bool, mask=m2)).new()
+    val = monoid.any(
+        one(m1.parent).new(bool, **opts) | one(m2.parent).new(bool, mask=m2, **opts)
+    ).new(**opts)
     return StructuralMask(val)
 
 
-def _combine_SV_S_mask_or(m1, m2):
+def _combine_SV_S_mask_or(m1, m2, opts):
     """V-S"""
-    val = monoid.any(one(m1.parent).new(bool, mask=m1) | one(m2.parent).new(bool)).new()
+    val = monoid.any(
+        one(m1.parent).new(bool, mask=m1, **opts) | one(m2.parent).new(bool, **opts)
+    ).new(**opts)
     return StructuralMask(val)
 
 
-def _complement_A_CS_mask_or(m1, m2):
+def _complement_A_CS_mask_or(m1, m2, opts):
     """~S-CS, ~V-CS, ~CV-CS"""
-    val = one(m2.parent).new(bool, mask=~m1)
+    val = one(m2.parent).new(bool, mask=~m1, **opts)
     return ComplementedStructuralMask(val)
 
 
-def _complement_CS_A_mask_or(m1, m2):
+def _complement_CS_A_mask_or(m1, m2, opts):
     """~CS-S, ~CS-V, ~CS-CV"""
-    val = one(m1.parent).new(bool, mask=~m2)
+    val = one(m1.parent).new(bool, mask=~m2, **opts)
     return ComplementedStructuralMask(val)
 
 
-def _complement_A_CV_mask_or(m1, m2):
+def _complement_A_CV_mask_or(m1, m2, opts):
     """~S-CV, ~V-CV"""
-    val = valuene(m2.parent).new(bool, mask=~m1)
+    val = valuene(m2.parent).new(bool, mask=~m1, **opts)
     return ComplementedStructuralMask(val)
 
 
-def _complement_CV_A_mask_or(m1, m2):
+def _complement_CV_A_mask_or(m1, m2, opts):
     """~CV-S, ~CV-V"""
-    val = valuene(m1.parent).new(bool, mask=~m2)
+    val = valuene(m1.parent).new(bool, mask=~m2, **opts)
     return ComplementedStructuralMask(val)
 
 
-def _combine_V_V_mask_or(m1, m2):
+def _combine_V_V_mask_or(m1, m2, opts):
     """V-V"""
-    val = monoid.any(valuene(m1.parent).new() | valuene(m2.parent).new()).new(bool)
+    val = monoid.any(valuene(m1.parent).new(**opts) | valuene(m2.parent).new(**opts)).new(
+        bool, **opts
+    )
     return StructuralMask(val)
 
 
-def _complement_CS_CS_mask_or(m1, m2):
+def _complement_CS_CS_mask_or(m1, m2, opts):
     """~CS-CS"""
-    val = pair(m1.parent & m2.parent).new(bool)
+    val = pair(m1.parent & m2.parent).new(bool, **opts)
     return ComplementedStructuralMask(val)
 
 
-def _complement_CV_CV_mask_or(m1, m2):
+def _complement_CV_CV_mask_or(m1, m2, opts):
     """~CV-CV"""
-    val = valuene(land(m1.parent & m2.parent).new(bool)).new()
+    val = valuene(land(m1.parent & m2.parent).new(bool, **opts)).new(**opts)
     return ComplementedStructuralMask(val)
 
 
