@@ -174,10 +174,11 @@ class Scalar(BaseType):
         base = object.__sizeof__(self)
         if self._is_cscalar:
             return base + self.gb_obj.__sizeof__() + ffi.sizeof(self.dtype.c_type)
-        else:
+        if backend == "suitesparse":
             size = ffi_new("size_t*")
             check_status(lib.GxB_Scalar_memoryUsage(size, self.gb_obj[0]), self)
             return base + size[0]
+        raise TypeError("Unable to get size of GrB_Scalar with backend: {backend}")
 
     def isequal(self, other, *, check_dtype=False):
         """Check for exact equality (including whether the value is missing).
@@ -215,17 +216,16 @@ class Scalar(BaseType):
             check_dtype = False
         if check_dtype and self.dtype != other.dtype:
             return False
-        elif self._is_empty:
+        if self._is_empty:
             return other._is_empty
-        elif other._is_empty:
+        if other._is_empty:
             return False
-        else:
-            # For now, compare values in Python
-            rv = self.value == other.value
-            try:
-                return bool(rv)
-            except ValueError:
-                return bool(rv.all())
+        # For now, compare values in Python
+        rv = self.value == other.value
+        try:
+            return bool(rv)
+        except ValueError:
+            return bool(rv.all())
 
     def isclose(self, other, *, rel_tol=1e-7, abs_tol=0.0, check_dtype=False):
         """Check for approximate equality (including whether the value is missing).
@@ -264,9 +264,9 @@ class Scalar(BaseType):
             check_dtype = False
         if check_dtype and self.dtype != other.dtype:
             return False
-        elif self._is_empty:
+        if self._is_empty:
             return other._is_empty
-        elif other._is_empty:
+        if other._is_empty:
             return False
         # We can't yet call a UDF on a scalar as part of the spec, so let's do it ourselves
         isclose_func = isclose(rel_tol, abs_tol)
@@ -335,10 +335,8 @@ class Scalar(BaseType):
             rv = np.array(ffi.buffer(scalar.gb_obj[0 : np_type.itemsize]))
             if np_type.subdtype is None:
                 return rv.view(np_type)[0]
-            else:
-                return rv.view(np_type.subdtype[0]).reshape(np_type.subdtype[1])
-        else:
-            return scalar.gb_obj[0]
+            return rv.view(np_type.subdtype[0]).reshape(np_type.subdtype[1])
+        return scalar.gb_obj[0]
 
     @value.setter
     def value(self, val):
@@ -450,8 +448,15 @@ class Scalar(BaseType):
                     new_scalar.value = self.value
         return new_scalar
 
-    def wait(self):
-        """Wait for a computation to complete.
+    def wait(self, how="materialize"):
+        """Wait for a computation to complete or establish a "happens-before" relation
+
+        Parameters
+        ----------
+        how : {"materialize", "complete"}
+            "materialize" fully computes an object.
+            "complete" establishes a "happens-before" relation useful with multi-threading.
+            See GraphBLAS documentation for more details.
 
         In `non-blocking mode <../user_guide/init.html#graphblas-modes>`__,
         the computations may be delayed and not yet safe to use by multiple threads.
@@ -459,9 +464,15 @@ class Scalar(BaseType):
 
         Has no effect in `blocking mode <../user_guide/init.html#graphblas-modes>`__.
         """
-        # TODO: expose COMPLETE or MATERIALIZE options to the user
+        how = how.lower()
+        if how == "materialize":
+            mode = _MATERIALIZE
+        elif how == "complete":
+            mode = _COMPLETE
+        else:
+            raise ValueError(f'`how` argument must be "materialize" or "complete"; got {how!r}')
         if not self._is_cscalar:
-            call("GrB_Scalar_wait", [self, _MATERIALIZE])
+            call("GrB_Scalar_wait", [self, mode])
 
     def get(self, default=None):
         """Get the internal value of the Scalar as a Python scalar.
@@ -538,41 +549,6 @@ class Scalar(BaseType):
     def _deserialize(value, dtype, is_cscalar, name):
         return Scalar.from_value(value, dtype, is_cscalar=is_cscalar, name=name)
 
-    def to_pygraphblas(self):  # pragma: no cover
-        """Convert to a ``pygraphblas.Scalar`` by making a copy of the internal value.
-
-        This method requires the
-        `pygraphblas <https://graphegon.github.io/pygraphblas/pygraphblas/index.html>`_
-        library to be installed.
-        """
-        if backend != "suitesparse":
-            raise RuntimeError(
-                f"to_pygraphblas only works with 'suitesparse' backend, not {backend}"
-            )
-        import pygraphblas as pg
-
-        return pg.Scalar.from_value(self.value)
-
-    @classmethod
-    def from_pygraphblas(cls, scalar):  # pragma: no cover
-        """Convert a ``pygraphblas.Scalar`` to a new :class:`Scalar` by making
-        a copy of the internal value.
-
-        This method requires the
-        `pygraphblas <https://graphegon.github.io/pygraphblas/pygraphblas/index.html>`_
-        library to be installed.
-        """
-        if backend != "suitesparse":
-            raise RuntimeError(
-                f"from_pygraphblas only works with 'suitesparse' backend, not {backend!r}"
-            )
-        import pygraphblas as pg
-
-        if not isinstance(scalar, pg.Scalar):
-            raise TypeError(f"Expected pygraphblas.Scalar object.  Got type: {type(scalar)}")
-        dtype = lookup_dtype(scalar.gb_type)
-        return cls.from_value(scalar[0], dtype)
-
     def _as_vector(self, *, name=None):
         """Copy or cast this Scalar to a Vector
 
@@ -580,12 +556,7 @@ class Scalar(BaseType):
         """
         from .vector import Vector
 
-        if self._is_cscalar:
-            rv = Vector(self.dtype, size=1, name=name)
-            if not self._is_empty:
-                rv[0] = self
-            return rv
-        else:
+        if backend == "suitesparse" and not self._is_cscalar:
             return Vector._from_obj(
                 ffi.cast("GrB_Vector*", self.gb_obj),
                 self.dtype,
@@ -593,6 +564,10 @@ class Scalar(BaseType):
                 parent=self,
                 name=f"(GrB_Vector){self.name or 's_temp'}" if name is None else name,
             )
+        rv = Vector(self.dtype, size=1, name=name)
+        if not self._is_empty:
+            rv[0] = self
+        return rv
 
     def _as_matrix(self, *, name=None):
         """Copy or cast this Scalar to a Matrix
@@ -601,12 +576,7 @@ class Scalar(BaseType):
         """
         from .matrix import Matrix
 
-        if self._is_cscalar:
-            rv = Matrix(self.dtype, ncols=1, nrows=1, name=name)
-            if not self._is_empty:
-                rv[0, 0] = self
-            return rv
-        else:
+        if backend == "suitesparse" and not self._is_cscalar:
             return Matrix._from_obj(
                 ffi.cast("GrB_Matrix*", self.gb_obj),
                 self.dtype,
@@ -615,6 +585,10 @@ class Scalar(BaseType):
                 parent=self,
                 name=f"(GrB_Matrix){self.name or 's_temp'}" if name is None else name,
             )
+        rv = Matrix(self.dtype, ncols=1, nrows=1, name=name)
+        if not self._is_empty:
+            rv[0, 0] = self
+        return rv
 
 
 class ScalarExpression(BaseExpression):
@@ -635,10 +609,10 @@ class ScalarExpression(BaseExpression):
             is_cscalar = self._is_cscalar
         return Scalar(dtype, is_cscalar=is_cscalar, name=name)
 
-    def new(self, dtype=None, *, is_cscalar=None, name=None):
+    def new(self, dtype=None, *, is_cscalar=None, name=None, **opts):
         if is_cscalar is None:
             is_cscalar = self._is_cscalar
-        return super()._new(dtype, None, name, is_cscalar=is_cscalar)
+        return super()._new(dtype, None, name, is_cscalar=is_cscalar, **opts)
 
     dup = new
 
@@ -679,7 +653,6 @@ class ScalarExpression(BaseExpression):
     name = wrapdoc(Scalar.name)(property(automethods.name))
     name = name.setter(automethods._set_name)
     nvals = wrapdoc(Scalar.nvals)(property(automethods.nvals))
-    to_pygraphblas = wrapdoc(Scalar.to_pygraphblas)(property(automethods.to_pygraphblas))
     value = wrapdoc(Scalar.value)(property(automethods.value))
     wait = wrapdoc(Scalar.wait)(property(automethods.wait))
     # These raise exceptions
@@ -699,11 +672,11 @@ class ScalarIndexExpr(AmbiguousAssignOrExtract):
     _is_scalar = True
     _is_cscalar = False
 
-    def new(self, dtype=None, *, is_cscalar=None, name=None):
+    def new(self, dtype=None, *, is_cscalar=None, name=None, **opts):
         if is_cscalar is None:
             is_cscalar = False
         return self.parent._extract_element(
-            self.resolved_indexes, dtype, is_cscalar=is_cscalar, name=name
+            self.resolved_indexes, dtype, opts, is_cscalar=is_cscalar, name=name
         )
 
     dup = new
@@ -740,7 +713,6 @@ class ScalarIndexExpr(AmbiguousAssignOrExtract):
     name = wrapdoc(Scalar.name)(property(automethods.name))
     name = name.setter(automethods._set_name)
     nvals = wrapdoc(Scalar.nvals)(property(automethods.nvals))
-    to_pygraphblas = wrapdoc(Scalar.to_pygraphblas)(property(automethods.to_pygraphblas))
     value = wrapdoc(Scalar.value)(property(automethods.value))
     wait = wrapdoc(Scalar.wait)(property(automethods.wait))
     # These raise exceptions
@@ -756,10 +728,9 @@ class ScalarIndexExpr(AmbiguousAssignOrExtract):
 def _as_scalar(scalar, dtype=None, *, is_cscalar):
     if type(scalar) is not Scalar:
         return Scalar.from_value(scalar, dtype, is_cscalar=is_cscalar, name="")
-    elif scalar._is_cscalar != is_cscalar or dtype is not None and scalar.dtype != dtype:
+    if scalar._is_cscalar != is_cscalar or dtype is not None and scalar.dtype != dtype:
         return scalar.dup(dtype, is_cscalar=is_cscalar, name=scalar.name)
-    else:
-        return scalar
+    return scalar
 
 
 def _dict_to_record(np_type, d):
@@ -775,6 +746,7 @@ def _dict_to_record(np_type, d):
 
 
 _MATERIALIZE = Scalar.from_value(lib.GrB_MATERIALIZE, is_cscalar=True, name="GrB_MATERIALIZE")
+_COMPLETE = Scalar.from_value(lib.GrB_COMPLETE, is_cscalar=True, name="GrB_COMPLETE")
 
 utils._output_types[Scalar] = Scalar
 utils._output_types[ScalarIndexExpr] = Scalar
