@@ -1,30 +1,28 @@
 import itertools
-import warnings
 
 import numpy as np
 from numba import njit
-from suitesparse_graphblas import vararg
 from suitesparse_graphblas.utils import claim_buffer, unclaim_buffer
 
 import graphblas as gb
 
-from ... import monoid
+from ... import binary, monoid
 from ...dtypes import _INDEX, INT64, UINT64, _string_to_dtype, lookup_dtype
 from ...exceptions import _error_code_lookup, check_status, check_status_carg
 from .. import NULL, ffi, lib
 from ..base import call
+from ..operator import get_typed_op
 from ..scalar import Scalar, _as_scalar
 from ..utils import (
     _CArray,
     _MatrixArray,
     ints_to_numpy_buffer,
-    libget,
     normalize_chunks,
     values_to_numpy_buffer,
     wrapdoc,
 )
 from .config import BaseConfig
-from .descriptor import get_compression_descriptor, get_nthreads_descriptor
+from .descriptor import get_descriptor
 from .matrix import _concat_mn
 from .prefix_scan import prefix_scan
 
@@ -64,8 +62,8 @@ class VectorConfig(BaseConfig):
         Current sparsity format
     """
 
-    _get_function = lib.GxB_Vector_Option_get
-    _set_function = lib.GxB_Vector_Option_set
+    _get_function = "GxB_Vector_Option_get"
+    _set_function = "GxB_Vector_Option_set"
     _options = {
         "bitmap_switch": (lib.GxB_BITMAP_SWITCH, "double"),
         "sparsity_control": (lib.GxB_SPARSITY_CONTROL, "int"),
@@ -75,24 +73,24 @@ class VectorConfig(BaseConfig):
     }
     _bitwise = {
         "sparsity_control": {
-            # lib.GxB_HYPERSPARSE: "hypersparse",  # For matrices, not vectors
-            lib.GxB_SPARSE: "sparse",
-            lib.GxB_BITMAP: "bitmap",
-            lib.GxB_FULL: "full",
-            lib.GxB_AUTO_SPARSITY: "auto",
+            # "hypersparse": lib.GxB_HYPERSPARSE,  # For matrices, not vectors
+            "sparse": lib.GxB_SPARSE,
+            "bitmap": lib.GxB_BITMAP,
+            "full": lib.GxB_FULL,
+            "auto": lib.GxB_AUTO_SPARSITY,
         },
     }
     _enumerations = {
         "format": {
-            lib.GxB_BY_ROW: "by_row",
-            lib.GxB_BY_COL: "by_col",
-            # lib.GxB_NO_FORMAT: "no_format",  # Used by iterators; not valid here
+            "by_row": lib.GxB_BY_ROW,
+            "by_col": lib.GxB_BY_COL,
+            # "no_format": lib.GxB_NO_FORMAT,  # Used by iterators; not valid here
         },
         "sparsity_status": {
-            lib.GxB_HYPERSPARSE: "hypersparse",
-            lib.GxB_SPARSE: "sparse",
-            lib.GxB_BITMAP: "bitmap",
-            lib.GxB_FULL: "full",
+            "hypersparse": lib.GxB_HYPERSPARSE,
+            "sparse": lib.GxB_SPARSE,
+            "bitmap": lib.GxB_BITMAP,
+            "full": lib.GxB_FULL,
         },
     }
     _defaults = {
@@ -130,9 +128,9 @@ class ss:
     @property
     def format(self):
         parent = self._parent
-        sparsity_ptr = ffi_new("GxB_Option_Field*")
+        sparsity_ptr = ffi_new("int32_t*")
         check_status(
-            lib.GxB_Vector_Option_get(parent._carg, lib.GxB_SPARSITY_STATUS, vararg(sparsity_ptr)),
+            lib.GxB_Vector_Option_get_INT32(parent._carg, lib.GxB_SPARSITY_STATUS, sparsity_ptr),
             parent,
         )
         sparsity_status = sparsity_ptr[0]
@@ -146,21 +144,7 @@ class ss:
             raise NotImplementedError(f"Unknown sparsity status: {sparsity_status}")
         return format
 
-    def diag(self, matrix, k=0):
-        """
-        GxB_Vector_diag
-
-        **This function is deprecated.  Use ``Matrix.diag`` or ``Vector.ss.build_diag`` instead.**
-
-        """
-        warnings.warn(
-            "`Vector.ss.diag` is deprecated; "
-            "please use `Matrix.diag` or `Vector.ss.build_diag` instead",
-            DeprecationWarning,
-        )
-        self.build_diag(matrix, k)
-
-    def build_diag(self, matrix, k=0):
+    def build_diag(self, matrix, k=0, **opts):
         """
         GxB_Vector_diag
 
@@ -193,9 +177,12 @@ class ss:
             # Transpose descriptor doesn't do anything, so use the parent
             k = -k
             matrix = matrix._matrix
-        call("GxB_Vector_diag", [self._parent, matrix, _as_scalar(k, INT64, is_cscalar=True), None])
+        call(
+            "GxB_Vector_diag",
+            [self._parent, matrix, _as_scalar(k, INT64, is_cscalar=True), get_descriptor(**opts)],
+        )
 
-    def split(self, chunks, *, name=None):
+    def split(self, chunks, *, name=None, **opts):
         """
         GxB_Matrix_split
 
@@ -231,7 +218,7 @@ class ss:
                 _CArray(tile_nrows),
                 _CArray([1]),
                 parent,
-                None,
+                get_descriptor(**opts),
             ],
         )
         rv = []
@@ -246,7 +233,7 @@ class ss:
             rv.append(tile)
         return rv
 
-    def _concat(self, tiles, m):
+    def _concat(self, tiles, m, opts):
         ctiles = ffi_new("GrB_Matrix[]", m)
         for i, tile in enumerate(tiles):
             ctiles[i] = tile.gb_obj[0]
@@ -257,11 +244,11 @@ class ss:
                 _MatrixArray(ctiles, name="tiles"),
                 _as_scalar(m, _INDEX, is_cscalar=True),
                 _as_scalar(1, _INDEX, is_cscalar=True),
-                None,
+                get_descriptor(**opts),
             ],
         )
 
-    def concat(self, tiles):
+    def concat(self, tiles, **opts):
         """
         GxB_Matrix_concat
 
@@ -277,7 +264,7 @@ class ss:
         graphblas.ss.concat
         """
         tiles, m, n, is_matrix = _concat_mn(tiles, is_matrix=False)
-        self._concat(tiles, m)
+        self._concat(tiles, m, opts)
 
     def build_scalar(self, indices, value):
         """
@@ -425,7 +412,7 @@ class ss:
         finally:
             lib.GxB_Iterator_free(it_ptr)
 
-    def export(self, format=None, *, sort=False, give_ownership=False, raw=False):
+    def export(self, format=None, *, sort=False, give_ownership=False, raw=False, **opts):
         """
         GxB_Vextor_export_xxx
 
@@ -468,7 +455,7 @@ class ss:
                 - size : int
                 - nvals : int, only present if raw == True
             - "bitmap" format
-                - bitmap : ndarray(dtype=bool8, size=size)
+                - bitmap : ndarray(dtype=bool, size=size)
                 - values : ndarray(size=size)
                     - Elements where bitmap is False are undefined
                 - nvals : int
@@ -486,10 +473,15 @@ class ss:
         >>> v2 = Vector.ss.import_any(**pieces)
         """
         return self._export(
-            format=format, sort=sort, give_ownership=give_ownership, raw=raw, method="export"
+            format=format,
+            sort=sort,
+            give_ownership=give_ownership,
+            raw=raw,
+            method="export",
+            opts=opts,
         )
 
-    def unpack(self, format=None, *, sort=False, raw=False):
+    def unpack(self, format=None, *, sort=False, raw=False, **opts):
         """
         GxB_Vector_unpack_xxx
 
@@ -498,9 +490,11 @@ class ss:
 
         See `Vector.ss.export` documentation for more details.
         """
-        return self._export(format=format, sort=sort, give_ownership=True, raw=raw, method="unpack")
+        return self._export(
+            format=format, sort=sort, give_ownership=True, raw=raw, method="unpack", opts=opts
+        )
 
-    def _export(self, format=None, *, sort=False, give_ownership=False, raw=False, method):
+    def _export(self, format=None, *, sort=False, give_ownership=False, raw=False, method, opts):
         if give_ownership:
             parent = self._parent
         else:
@@ -529,12 +523,14 @@ class ss:
         else:
             jumbled = ffi_new("bool*")
         is_iso = ffi_new("bool*")
+        desc = get_descriptor(**opts)
+        desc_obj = NULL if desc is None else desc._carg
         if format == "sparse":
             vi = ffi_new("GrB_Index**")
             vi_size = ffi_new("GrB_Index*")
             nvals = ffi_new("GrB_Index*")
             check_status(
-                libget(f"GxB_Vector_{method}_CSC")(
+                getattr(lib, f"GxB_Vector_{method}_CSC")(
                     vhandle,
                     *args,
                     vi,
@@ -544,7 +540,7 @@ class ss:
                     is_iso,
                     nvals,
                     jumbled,
-                    NULL,
+                    desc_obj,
                 ),
                 parent,
             )
@@ -573,13 +569,21 @@ class ss:
             vb_size = ffi_new("GrB_Index*")
             nvals = ffi_new("GrB_Index*")
             check_status(
-                libget(f"GxB_Vector_{method}_Bitmap")(
-                    vhandle, *args, vb, vx, vb_size, vx_size, is_iso, nvals, NULL
+                getattr(lib, f"GxB_Vector_{method}_Bitmap")(
+                    vhandle,
+                    *args,
+                    vb,
+                    vx,
+                    vb_size,
+                    vx_size,
+                    is_iso,
+                    nvals,
+                    desc_obj,
                 ),
                 parent,
             )
             is_iso = is_iso[0]
-            bool_dtype = np.dtype(np.bool8)
+            bool_dtype = np.dtype(np.bool_)
             bitmap = claim_buffer(ffi, vb[0], vb_size[0] // bool_dtype.itemsize, bool_dtype)
             values = claim_buffer(ffi, vx[0], vx_size[0] // dtype.itemsize, dtype)
             if not raw:
@@ -599,7 +603,14 @@ class ss:
                 rv["size"] = size
         elif format == "full":
             check_status(
-                libget(f"GxB_Vector_{method}_Full")(vhandle, *args, vx, vx_size, is_iso, NULL),
+                getattr(lib, f"GxB_Vector_{method}_Full")(
+                    vhandle,
+                    *args,
+                    vx,
+                    vx_size,
+                    is_iso,
+                    desc_obj,
+                ),
                 parent,
             )
             is_iso = is_iso[0]
@@ -637,6 +648,7 @@ class ss:
         size=None,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         format=None,
         dtype=None,
         name=None,
@@ -647,6 +659,7 @@ class ss:
         bitmap=None,
         # Bitmap/Sparse
         nvals=None,  # optional
+        **opts,
     ):
         """
         GxB_Vector_import_xxx
@@ -678,6 +691,7 @@ class ss:
             size=size,
             is_iso=is_iso,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             format=format,
             dtype=dtype,
             name=name,
@@ -689,6 +703,7 @@ class ss:
             # Bitmap/Sparse
             nvals=nvals,
             method="import",
+            opts=opts,
         )
 
     def pack_any(
@@ -698,6 +713,7 @@ class ss:
         values,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         format=None,
         # Sparse
         indices=None,
@@ -706,10 +722,11 @@ class ss:
         bitmap=None,
         # Bitmap/Sparse
         nvals=None,  # optional
-        # Unused for pack
+        # Unused for pack, ignored
         size=None,
         dtype=None,
         name=None,
+        **opts,
     ):
         """
         GxB_Vector_pack_xxx
@@ -723,6 +740,7 @@ class ss:
             values=values,
             is_iso=is_iso,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             format=format,
             # Sparse
             indices=indices,
@@ -733,6 +751,7 @@ class ss:
             nvals=nvals,
             method="pack",
             vector=self._parent,
+            opts=opts,
         )
 
     @classmethod
@@ -744,6 +763,7 @@ class ss:
         size=None,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         format=None,
         dtype=None,
         name=None,
@@ -756,6 +776,7 @@ class ss:
         nvals=None,  # optional
         method,
         vector=None,
+        opts,
     ):
         if format is None:
             if indices is not None:
@@ -781,8 +802,10 @@ class ss:
                 is_iso=is_iso,
                 sorted_index=sorted_index,
                 take_ownership=take_ownership,
+                secure_import=secure_import,
                 dtype=dtype,
                 name=name,
+                **opts,
             )
         if format == "bitmap":
             return getattr(obj, f"{method}_bitmap")(
@@ -792,8 +815,10 @@ class ss:
                 size=size,
                 is_iso=is_iso,
                 take_ownership=take_ownership,
+                secure_import=secure_import,
                 dtype=dtype,
                 name=name,
+                **opts,
             )
         if format == "full":
             return getattr(obj, f"{method}_full")(
@@ -801,8 +826,10 @@ class ss:
                 size=size,
                 is_iso=is_iso,
                 take_ownership=take_ownership,
+                secure_import=secure_import,
                 dtype=dtype,
                 name=name,
+                **opts,
             )
         raise ValueError(f"Invalid format: {format}")
 
@@ -817,9 +844,11 @@ class ss:
         is_iso=False,
         sorted_index=False,
         take_ownership=False,
+        secure_import=False,
         dtype=None,
         format=None,
         name=None,
+        **opts,
     ):
         """
         GxB_Vector_import_CSC
@@ -872,10 +901,12 @@ class ss:
             is_iso=is_iso,
             sorted_index=sorted_index,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             dtype=dtype,
             format=format,
             name=name,
             method="import",
+            opts=opts,
         )
 
     def pack_sparse(
@@ -887,8 +918,13 @@ class ss:
         is_iso=False,
         sorted_index=False,
         take_ownership=False,
+        secure_import=False,
         format=None,
-        **ignored_kwargs,
+        # Unused for pack, ignored
+        size=None,
+        dtype=None,
+        name=None,
+        **opts,
     ):
         """
         GxB_Vector_pack_CSC
@@ -905,9 +941,11 @@ class ss:
             is_iso=is_iso,
             sorted_index=sorted_index,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             format=format,
             method="pack",
             vector=self._parent,
+            opts=opts,
         )
 
     @classmethod
@@ -921,11 +959,13 @@ class ss:
         is_iso=False,
         sorted_index=False,
         take_ownership=False,
+        secure_import=False,
         dtype=None,
         format=None,
         name=None,
         method,
         vector=None,
+        opts,
     ):
         if format is not None and format.lower() != "sparse":
             raise ValueError(f"Invalid format: {format!r}.  Must be None or 'sparse'.")
@@ -951,7 +991,8 @@ class ss:
         else:
             vhandle = vector._carg
             args = ()
-        status = libget(f"GxB_Vector_{method}_CSC")(
+        desc = get_descriptor(secure_import=secure_import, **opts)
+        status = getattr(lib, f"GxB_Vector_{method}_CSC")(
             vhandle,
             *args,
             vi,
@@ -961,7 +1002,7 @@ class ss:
             is_iso,
             nvals,
             not sorted_index,
-            NULL,
+            NULL if desc is None else desc._carg,
         )
         if method == "import":
             check_status_carg(
@@ -986,9 +1027,11 @@ class ss:
         size=None,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         dtype=None,
         format=None,
         name=None,
+        **opts,
     ):
         """
         GxB_Vector_import_Bitmap
@@ -1013,7 +1056,7 @@ class ss:
             to GraphBLAS if possible.  To give ownership of the underlying
             memory buffers to GraphBLAS, the arrays must:
                 - be C contiguous
-                - have the correct dtype (bool8 for bitmap)
+                - have the correct dtype (bool for bitmap)
                 - own its own data
                 - be writeable
             If all of these conditions are not met, then the data will be
@@ -1040,10 +1083,12 @@ class ss:
             size=size,
             is_iso=is_iso,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             dtype=dtype,
             format=format,
             name=name,
             method="import",
+            opts=opts,
         )
 
     def pack_bitmap(
@@ -1054,8 +1099,13 @@ class ss:
         nvals=None,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         format=None,
-        **unused_kwargs,
+        # Unused for pack, ignored
+        size=None,
+        dtype=None,
+        name=None,
+        **opts,
     ):
         """
         GxB_Vector_pack_Bitmap
@@ -1071,9 +1121,11 @@ class ss:
             nvals=nvals,
             is_iso=is_iso,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             format=format,
             method="pack",
             vector=self._parent,
+            opts=opts,
         )
 
     @classmethod
@@ -1086,16 +1138,18 @@ class ss:
         size=None,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         dtype=None,
         format=None,
         name=None,
         method,
         vector=None,
+        opts,
     ):
         if format is not None and format.lower() != "bitmap":
             raise ValueError(f"Invalid format: {format!r}.  Must be None or 'bitmap'.")
         copy = not take_ownership
-        bitmap = ints_to_numpy_buffer(bitmap, np.bool8, copy=copy, ownable=True, name="bitmap")
+        bitmap = ints_to_numpy_buffer(bitmap, np.bool_, copy=copy, ownable=True, name="bitmap")
         if method == "pack":
             dtype = vector.dtype
             size = vector._size
@@ -1123,7 +1177,8 @@ class ss:
         else:
             vhandle = vector._carg
             args = ()
-        status = libget(f"GxB_Vector_{method}_Bitmap")(
+        desc = get_descriptor(secure_import=secure_import, **opts)
+        status = getattr(lib, f"GxB_Vector_{method}_Bitmap")(
             vhandle,
             *args,
             vb,
@@ -1132,7 +1187,7 @@ class ss:
             values.nbytes,
             is_iso,
             nvals,
-            NULL,
+            NULL if desc is None else desc._carg,
         )
         if method == "import":
             check_status_carg(
@@ -1155,9 +1210,11 @@ class ss:
         size=None,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         dtype=None,
         format=None,
         name=None,
+        **opts,
     ):
         """
         GxB_Vector_import_Full
@@ -1178,7 +1235,7 @@ class ss:
             to GraphBLAS if possible.  To give ownership of the underlying
             memory buffers to GraphBLAS, the arrays must:
                 - be C contiguous
-                - have the correct dtype (bool8 for bitmap)
+                - have the correct dtype (bool for bitmap)
                 - own its own data
                 - be writeable
             If all of these conditions are not met, then the data will be
@@ -1203,10 +1260,12 @@ class ss:
             size=size,
             is_iso=is_iso,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             dtype=dtype,
             format=format,
             name=name,
             method="import",
+            opts=opts,
         )
 
     def pack_full(
@@ -1215,8 +1274,13 @@ class ss:
         *,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         format=None,
-        **unused_kwargs,
+        # Unused for pack, ignored
+        size=None,
+        dtype=None,
+        name=None,
+        **opts,
     ):
         """
         GxB_Vector_pack_Full
@@ -1230,9 +1294,11 @@ class ss:
             values=values,
             is_iso=is_iso,
             take_ownership=take_ownership,
+            secure_import=secure_import,
             format=format,
             method="pack",
             vector=self._parent,
+            opts=opts,
         )
 
     @classmethod
@@ -1243,11 +1309,13 @@ class ss:
         size=None,
         is_iso=False,
         take_ownership=False,
+        secure_import=False,
         dtype=None,
         format=None,
         name=None,
         method,
         vector=None,
+        opts,
     ):
         if format is not None and format.lower() != "full":
             raise ValueError(f"Invalid format: {format!r}.  Must be None or 'full'.")
@@ -1269,13 +1337,14 @@ class ss:
         else:
             vhandle = vector._carg
             args = ()
-        status = libget(f"GxB_Vector_{method}_Full")(
+        desc = get_descriptor(secure_import=secure_import, **opts)
+        status = getattr(lib, f"GxB_Vector_{method}_Full")(
             vhandle,
             *args,
             vx,
             values.nbytes,
             is_iso,
-            NULL,
+            NULL if desc is None else desc._carg,
         )
         if method == "import":
             check_status_carg(
@@ -1293,7 +1362,7 @@ class ss:
     def head(self, n=10, dtype=None, *, sort=False):
         return head(self._parent, n, dtype, sort=sort)
 
-    def scan(self, op=monoid.plus, *, name=None):
+    def scan(self, op=monoid.plus, *, name=None, **opts):
         """Perform a prefix scan with the given monoid.
 
         For example, use `monoid.plus` (the default) to perform a cumulative sum,
@@ -1303,9 +1372,9 @@ class ss:
         -------
         Scalar
         """
-        return prefix_scan(self._parent, op, name=name, within="scan")
+        return prefix_scan(self._parent, op, name=name, within="scan", **opts)
 
-    def reshape(self, nrows, ncols=None, order="rowwise", *, name=None):
+    def reshape(self, nrows, ncols=None, order="rowwise", *, name=None, **opts):
         """Return a copy of the Vector as a Matrix of the given shape.
 
         The shape of the Matrix must be compatible with the original shape.
@@ -1333,7 +1402,7 @@ class ss:
         --------
         Matrix.ss.flatten : flatten a Matrix into a Vector.
         """
-        return self._parent._as_matrix().ss.reshape(nrows, ncols, order, name=name)
+        return self._parent._as_matrix().ss.reshape(nrows, ncols, order, name=name, **opts)
 
     def selectk(self, how, k, *, name=None):
         """Select (up to) k elements.
@@ -1490,7 +1559,68 @@ class ss:
             name=name,
         )
 
-    def serialize(self, compression="default", level=None, *, nthreads=None):
+    def sort(self, op=binary.lt, *, values=True, permutation=True, **opts):
+        """GxB_Vector_sort to sort values of the Vector
+
+        Sorting moves all the elements to the left just like `compactify`.
+        The returned vectors will be the same size as the input Vector.
+
+        Parameters
+        ----------
+        op : :class:`~graphblas.core.operator.BinaryOp`, optional
+            Binary operator with a bool return type used to sort the values.
+            For example, `binary.lt` (the default) sorts the smallest elements first.
+            Ties are broken according to indices (smaller first).
+        values : bool, default=True
+            Whether to return values; will return `None` for values if `False`.
+        permutation : bool, default=True
+            Whether to compute the permutation Vector that has the original indices of the
+            sorted values. Will return None if `False`.
+        nthreads : int, optional
+            The maximum number of threads to use for this operation.
+            None, 0 or negative nthreads means to use the default number of threads.
+
+        Returns
+        -------
+        Vector : values
+        Vector[dtype=UINT64] : permutation
+
+        See Also
+        --------
+        Vector.ss.compactify
+        """
+        from ..vector import Vector
+
+        parent = self._parent
+        op = get_typed_op(op, parent.dtype, kind="binary")
+        if op.opclass == "Monoid":
+            op = op.binaryop
+        else:
+            parent._expect_op(op, "BinaryOp", within="sort", argname="op")
+        if values:
+            w = Vector(parent.dtype, parent._size, name="values")
+        elif not permutation:
+            return None, None
+        else:
+            w = None
+        if permutation:
+            p = Vector(UINT64, parent._size, name="permutation")
+        else:
+            p = None
+        desc = get_descriptor(**opts)
+        check_status(
+            lib.GxB_Vector_sort(
+                NULL if w is None else w._carg,
+                NULL if p is None else p._carg,
+                op._carg,
+                parent._carg,
+                NULL if desc is None else desc._carg,
+            ),
+            parent,
+        )
+        return w, p
+
+    def serialize(self, compression="default", level=None, **opts):
         """Serialize a Vector to bytes (as numpy array) using SuiteSparse GxB_Vector_serialize.
 
         Parameters
@@ -1519,7 +1649,7 @@ class ss:
 
         *Warning*: Behavior of serializing UDTs is experimental and may change in a future release.
         """
-        desc = get_compression_descriptor(compression, level=level, nthreads=nthreads)
+        desc = get_descriptor(compression=compression, compression_level=level, **opts)
         blob_handle = ffi_new("void**")
         blob_size_handle = ffi_new("GrB_Index*")
         parent = self._parent
@@ -1528,14 +1658,14 @@ class ss:
                 blob_handle,
                 blob_size_handle,
                 parent._carg,
-                desc._carg,
+                NULL if desc is None else desc._carg,
             ),
             parent,
         )
         return claim_buffer(ffi, blob_handle[0], blob_size_handle[0], np.dtype(np.uint8))
 
     @classmethod
-    def deserialize(cls, data, dtype=None, *, nthreads=None, name=None):
+    def deserialize(cls, data, dtype=None, *, name=None, **opts):
         """Deserialize a Vector from bytes, buffer, or numpy array using GxB_Vector_deserialize.
 
         The data should have been previously serialized with a compatible version of
@@ -1577,13 +1707,12 @@ class ss:
             dtype = _string_to_dtype(dtype_name)
         else:
             dtype = lookup_dtype(dtype)
-        if nthreads is not None:
-            desc_obj = get_nthreads_descriptor(nthreads)._carg
-        else:
-            desc_obj = NULL
+        desc = get_descriptor(**opts)
         gb_obj = ffi_new("GrB_Vector*")
         check_status_carg(
-            lib.GxB_Vector_deserialize(gb_obj, dtype._carg, data_obj, data.nbytes, desc_obj),
+            lib.GxB_Vector_deserialize(
+                gb_obj, dtype._carg, data_obj, data.nbytes, NULL if desc is None else desc._carg
+            ),
             "Vector",
             gb_obj[0],
         )
