@@ -1,7 +1,5 @@
 from collections.abc import Mapping
 
-from suitesparse_graphblas import vararg
-
 from ..core import ffi, lib
 from ..core.base import _expect_type
 from ..core.matrix import Matrix, TransposedMatrix
@@ -21,7 +19,7 @@ _graphblas_ss.__name__ = "graphblas.ss"
 _graphblas_ss = _graphblas_ss()
 
 
-def diag(x, k=0, dtype=None, *, name=None):
+def diag(x, k=0, dtype=None, *, name=None, **opts):
     """
     GxB_Matrix_diag, GxB_Vector_diag
 
@@ -66,11 +64,11 @@ def diag(x, k=0, dtype=None, *, name=None):
         if size < 0:
             size = 0
         rv = Vector(dtype, size=size, name=name)
-        rv.ss.build_diag(x, k)
+        rv.ss.build_diag(x, k, **opts)
     return rv
 
 
-def concat(tiles, dtype=None, *, name=None):
+def concat(tiles, dtype=None, *, name=None, **opts):
     """
     GxB_Matrix_concat
 
@@ -97,13 +95,13 @@ def concat(tiles, dtype=None, *, name=None):
         nrows = sum(row_tiles[0]._nrows for row_tiles in tiles)
         ncols = sum(tile._ncols for tile in tiles[0])
         rv = Matrix(dtype, nrows=nrows, ncols=ncols, name=name)
-        rv.ss._concat(tiles, m, n)
+        rv.ss._concat(tiles, m, n, opts)
     else:
         if dtype is None:
             dtype = tiles[0].dtype
         size = sum(tile._nrows for tile in tiles)
         rv = Vector(dtype, size=size, name=name)
-        rv.ss._concat(tiles, m)
+        rv.ss._concat(tiles, m, opts)
     return rv
 
 
@@ -132,8 +130,8 @@ class GlobalConfig(BaseConfig):
     Setting values to None restores the default value for most configurations.
     """
 
-    _get_function = lib.GxB_Global_Option_get
-    _set_function = lib.GxB_Global_Option_set
+    _get_function = "GxB_Global_Option_get"
+    _set_function = "GxB_Global_Option_set"
     _null_valid = {"bitmap_switch"}
     _options = {
         # Matrix/Vector format
@@ -164,13 +162,13 @@ class GlobalConfig(BaseConfig):
     }
     _enumerations = {
         "format": {
-            lib.GxB_BY_ROW: "by_row",
-            lib.GxB_BY_COL: "by_col",
-            # lib.GxB_NO_FORMAT: "no_format",  # Used by iterators; not valid here
+            "by_row": lib.GxB_BY_ROW,
+            "by_col": lib.GxB_BY_COL,
+            # "no_format": lib.GxB_NO_FORMAT,  # Used by iterators; not valid here
         },
         "gpu_control": {
-            lib.GxB_GPU_ALWAYS: "always",
-            lib.GxB_GPU_NEVER: "never",
+            "always": lib.GxB_GPU_ALWAYS,
+            "never": lib.GxB_GPU_NEVER,
         },
     }
 
@@ -210,28 +208,28 @@ class About(Mapping):
     def __getitem__(self, key):
         key = key.lower()
         if key in self._mode_options:
-            val_ptr = ffi.new("GrB_Mode*")
-            info = lib.GxB_Global_Option_get(self._mode_options[key], vararg(val_ptr))
+            val_ptr = ffi.new("int32_t*")
+            info = lib.GxB_Global_Option_get_INT32(self._mode_options[key], val_ptr)
             if info == lib.GrB_SUCCESS:  # pragma: no branch (safety)
                 val = val_ptr[0]
                 if val not in self._modes:  # pragma: no cover (sanity)
                     raise ValueError(f"Unknown mode: {val}")
                 return self._modes[val]
         elif key in self._int3_options:
-            val_ptr = ffi.new("int[3]")
-            info = lib.GxB_Global_Option_get(self._int3_options[key], vararg(val_ptr))
+            val_ptr = ffi.new("int32_t[3]")
+            info = lib.GxB_Global_Option_get_INT32(self._int3_options[key], val_ptr)
             if info == lib.GrB_SUCCESS:  # pragma: no branch (safety)
                 return (val_ptr[0], val_ptr[1], val_ptr[2])
         elif key in self._str_options:
             val_ptr = ffi.new("char**")
-            info = lib.GxB_Global_Option_get(self._str_options[key], vararg(val_ptr))
+            info = lib.GxB_Global_Option_get_CHAR(self._str_options[key], val_ptr)
             if info == lib.GrB_SUCCESS:  # pragma: no branch (safety)
                 return ffi.string(val_ptr[0]).decode()
         elif key in self._bool_options:
-            val_ptr = ffi.new("bool*")
-            info = lib.GxB_Global_Option_get(self._bool_options[key], vararg(val_ptr))
+            val_ptr = ffi.new("int32_t*")
+            info = lib.GxB_Global_Option_get_INT32(self._bool_options[key], val_ptr)
             if info == lib.GrB_SUCCESS:  # pragma: no branch (safety)
-                return val_ptr[0]
+                return bool(val_ptr[0])
         else:
             raise KeyError(key)
         raise _error_code_lookup[info](f"Failed to get info for {key}")  # pragma: no cover (safety)
