@@ -2,10 +2,10 @@ if __name__ == "__main__":
     import pytest
     import suitesparse_graphblas as ssgb
 
-    import graphblas
+    import graphblas as gb
 
     ssgb.initialize(blocking=False)
 
     with pytest.raises(RuntimeError, match="GraphBLAS has already been initialized with"):
-        graphblas.init(blocking=True)
-    graphblas.init(blocking=False)
+        gb.init(blocking=True)
+    gb.init(blocking=False)
