@@ -12,6 +12,7 @@ import graphblas as gb
 from graphblas import agg, backend, binary, dtypes, indexunary, monoid, select, semiring, unary
 from graphblas.exceptions import (
     DimensionMismatch,
+    DomainMismatch,
     EmptyObject,
     IndexOutOfBound,
     InvalidObject,
@@ -894,7 +895,7 @@ def test_reduce_agg(v):
     silly = agg.Aggregator(
         "silly",
         composite=[agg.varp, agg.stdp],
-        finalize=lambda x, y: binary.times(x & y),
+        finalize=lambda x, y, opts: binary.times(x & y),
         types=[agg.varp],
     )
     s = v.reduce(silly).new()
@@ -911,7 +912,7 @@ def test_reduce_agg_argminmax(v):
     silly = agg.Aggregator(
         "silly",
         composite=[agg.argmin, agg.argmax],
-        finalize=lambda x, y: binary.plus(x & y),
+        finalize=lambda x, y, opts: binary.plus(x & y),
         types=[agg.argmin],
     )
     s = v.reduce(silly).new()
@@ -929,7 +930,7 @@ def test_reduce_agg_firstlast(v):
     silly = agg.Aggregator(
         "silly",
         composite=[agg.first, agg.last],
-        finalize=lambda x, y: binary.plus(x & y),
+        finalize=lambda x, y, opts: binary.plus(x & y),
         types=[agg.first],
     )
     s = v.reduce(silly).new()
@@ -943,7 +944,7 @@ def test_reduce_agg_firstlast_index(v):
     silly = agg.Aggregator(
         "silly",
         composite=[agg.first_index, agg.last_index],
-        finalize=lambda x, y: binary.plus(x & y),
+        finalize=lambda x, y, opts: binary.plus(x & y),
         types=[agg.first_index],
     )
     s = v.reduce(silly).new()
@@ -1350,6 +1351,10 @@ def test_wait(v):
     v2 = v.dup()
     v2.wait()
     assert v2.isequal(v)
+    v2.wait("materialize")
+    v2.wait("complete")
+    with pytest.raises(ValueError):
+        v2.wait("badmode")
 
 
 def test_pickle(v):
@@ -1594,7 +1599,6 @@ def test_expr_is_like_vector(v):
         "clear",
         "from_coo",
         "from_dict",
-        "from_pygraphblas",
         "from_values",
         "resize",
         "update",
@@ -1631,7 +1635,6 @@ def test_index_expr_is_like_vector(v):
         "clear",
         "from_coo",
         "from_dict",
-        "from_pygraphblas",
         "from_values",
         "resize",
     }
@@ -2399,3 +2402,35 @@ def test_to_dict(v):
     assert v.to_dict() == {1: 1, 3: 1, 4: 2, 6: 0}
     empty = Vector(int, 2)
     assert empty.to_dict() == {}
+
+
+@pytest.mark.skipif("not suitesparse")
+def test_ss_sort(v):
+    # For equal values, indices are guaranteed to be sorted
+    expected_p = Vector.from_coo([0, 1, 2, 3], [6, 1, 3, 4], size=7)
+    expected_w = Vector.from_coo([0, 1, 2, 3], [0, 1, 1, 2], size=7)
+    for permutation, values, nthreads in itertools.product([True, False], [True, False], [None, 4]):
+        w, p = v.ss.sort(permutation=permutation, values=values, nthreads=nthreads)
+        if values:
+            assert w.isequal(expected_w)
+        else:
+            assert w is None
+        if permutation:
+            assert p.isequal(expected_p)
+        else:
+            assert p is None
+    w, _ = v.ss.sort(">", permutation=False)
+    expected = Vector.from_coo([0, 1, 2, 3], [2, 1, 1, 0], size=7)
+    assert w.isequal(expected)
+    with pytest.raises(DomainMismatch):
+        v.ss.sort(binary.plus)
+
+    # Like compactify
+    _, p = v.ss.sort(lambda x, y: False, values=False)  # pragma: no branch (numba)
+    expected_p = Vector.from_coo([0, 1, 2, 3], [1, 3, 4, 6], size=7)
+    assert p.isequal(expected_p)
+    # reversed
+    _, p = v.ss.sort(binary.pair[bool], values=False)
+    expected_p = Vector.from_coo([0, 1, 2, 3], [6, 4, 3, 1], size=7)
+    assert p.isequal(expected_p)
+    w, p = v.ss.sort(monoid.lxor)  # Weird, but user-defined monoids may not commute, so okay
